@@ -261,6 +261,7 @@ def style_filter(cell: Cell, **kwargs: Any) -> Optional[Style]:
     writer = kwargs["writer"]
     report_color = kwargs["report_color"]
     color_map = kwargs["color_map"]
+    num_rows = kwargs["num_rows"]
     fg_color = None
     bg_color = None
 
@@ -275,6 +276,9 @@ def style_filter(cell: Cell, **kwargs: Any) -> Optional[Style]:
         return Style(font_weight="bold")
 
     retriever = ColorRetriever(cell.row, is_grayout, report_color, color_map)
+    is_passed = False
+    is_failed = False
+    is_skipped = False
 
     headers = writer.headers
     if headers[cell.col] in (Header.FILEPATH, Header.TESTFUNC):
@@ -284,10 +288,6 @@ def style_filter(cell: Cell, **kwargs: Any) -> Optional[Style]:
                 writer.value_matrix[cell.row][headers.index("error")],
             ]
         )
-        if error_count > 0:
-            fg_color, bg_color = retriever.retrieve_fg_bg_color(color_map[FGColor.ERROR])
-            return Style(color=fg_color, bg_color=bg_color)
-
         skip_count = sum(
             [
                 writer.value_matrix[cell.row][headers.index("skipped")],
@@ -295,31 +295,35 @@ def style_filter(cell: Cell, **kwargs: Any) -> Optional[Style]:
                 writer.value_matrix[cell.row][headers.index("xpassed")],
             ]
         )
-        if skip_count > 0:
-            fg_color, bg_color = retriever.retrieve_fg_bg_color(color_map[FGColor.SKIP])
-            return Style(color=fg_color, bg_color=bg_color)
 
-        fg_color, bg_color = retriever.retrieve_fg_bg_color(color_map[FGColor.SUCCESS])
-        return Style(color=fg_color, bg_color=bg_color)
+        is_failed = error_count > 0
+        is_skipped = skip_count > 0
+        is_passed = error_count == 0 and skip_count == 0
 
-    if headers[cell.col] in ("passed"):
+    if is_passed or headers[cell.col] in ("passed"):
         fg_color, bg_color = retriever.retrieve_fg_bg_color(color_map[FGColor.SUCCESS])
-    elif headers[cell.col] in ("failed", "error"):
+    elif is_failed or headers[cell.col] in ("failed", "error"):
         fg_color, bg_color = retriever.retrieve_fg_bg_color(color_map[FGColor.ERROR])
-    if headers[cell.col] in ("skipped", "xfailed", "xpassed"):
+    elif is_skipped or headers[cell.col] in ("skipped", "xfailed", "xpassed"):
         fg_color, bg_color = retriever.retrieve_fg_bg_color(color_map[FGColor.SKIP])
 
+    if cell.row == num_rows - 1:
+        bg_color = BGColor.TOTAL_ROW
+
     return Style(color=fg_color, bg_color=bg_color)
 
 
 def col_separator_style_filter(
     left_cell: Optional[Cell], right_cell: Optional[Cell], **kwargs: Any
 ) -> Optional[Style]:
+    num_rows = kwargs["num_rows"]
     fg_color = None
     bg_color = None
     row = left_cell.row if left_cell else cast(Cell, right_cell).row
 
-    if row % 2 == 0:
+    if row == num_rows - 1:
+        bg_color = BGColor.TOTAL_ROW
+    elif row % 2 == 0:
         bg_color = BGColor.EVEN_ROW
     elif row >= 0:
         bg_color = BGColor.ODD_ROW
@@ -333,7 +337,6 @@ def col_separator_style_filter(
 def make_md_report(
     config: Config, reporter: TerminalReporter, total_stats: Mapping[str, int]
 ) -> str:
-    verbosity_level = 1
     verbosity_level = retrieve_verbosity_level(config)
 
     outcomes = ["passed", "failed", "error", "skipped", "xfailed", "xpassed"]
@@ -392,6 +395,7 @@ def make_md_report(
                 ),
                 FGColor.GRAYOUT: Default.FGColor.GRAYOUT,
             },
+            "num_rows": len(writer.value_matrix),
         }
         writer.add_style_filter(style_filter)
 
